==> kpilot-trinity_3.5.13.2.orig.tar.xz: kpilot-trinity-3.5.13.2/conduits/knotes/knotes-factory.h <==
#ifndef _KPILOT_NULL_FACTORY_H
#define _KPILOT_NULL_FACTORY_H
/* null-factory.h                       KPilot
**
** Copyright (C) 2001,2003 by Dan Pilone
**
** This file defines the factory for the null-conduit plugin.
** It also defines the class for the behavior of the setup dialog.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include <klibloader.h>

class KInstance;
class KAboutData;

class KNotesConduitFactory : public KLibFactory
{
Q_OBJECT
  TQ_OBJECT

public:
	KNotesConduitFactory(TQObject * = 0L,const char * = 0L);
	virtual ~KNotesConduitFactory();

	static KAboutData *about() { return fAbout; } ;

	// The KNotes instance, unlike previous conduits (alphabetically)
	// has const char * const members. The extra const prevents people
	// from assigning to this variable, so you have to work hard to
	// break its value. We store group and entry keys in here.

protected:
	virtual TQObject* createObject( TQObject* parent = 0,
		const char* name = 0,
		const char* classname = TQOBJECT_OBJECT_NAME_STRING,
		const TQStringList &args = TQStringList() );
private:
	KInstance *fInstance;
	static KAboutData *fAbout;
} ;

extern "C"
{

void *init_libknotesconduit();

}


#endif

==> kpilot-trinity_14.0.13.orig.tar.xz: kpilot-trinity-14.0.13/conduits/knotes/knotes-factory.h <==
#ifndef _KPILOT_NULL_FACTORY_H
#define _KPILOT_NULL_FACTORY_H
/* null-factory.h                       KPilot
**
** Copyright (C) 2001,2003 by Dan Pilone
**
** This file defines the factory for the null-conduit plugin.
** It also defines the class for the behavior of the setup dialog.
*/

/*
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program in a file called COPYING; if not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
** MA 02110-1301, USA.
*/

/*
** Bug reports and questions can be sent to kde-pim@kde.org
*/

#include <klibloader.h>

class TDEInstance;
class TDEAboutData;

class KNotesConduitFactory : public KLibFactory
{
Q_OBJECT
  

public:
	KNotesConduitFactory(TQObject * = 0L,const char * = 0L);
	virtual ~KNotesConduitFactory();

	static TDEAboutData *about() { return fAbout; } ;

	// The KNotes instance, unlike previous conduits (alphabetically)
	// has const char * const members. The extra const prevents people
	// from assigning to this variable, so you have to work hard to
	// break its value. We store group and entry keys in here.

protected:
	virtual TQObject* createObject( TQObject* parent = 0,
		const char* name = 0,
		const char* classname = TQOBJECT_OBJECT_NAME_STRING,
		const TQStringList &args = TQStringList() );
private:
	TDEInstance *fInstance;
	static TDEAboutData *fAbout;
} ;

extern "C"
{

void *init_libknotesconduit();

}


#endif
